import type { NextApiHandler, NextApiRequest, NextApiResponse } from 'next';
/**
 *  public builder method of RouterBuilder that accepts next.js handler
 *  and return RouterBuilder itself
 */
export declare type RouterHandler<T = unknown> = (handler: NextHandler<T>) => RouterBuilder;
/**
 *  a standard next.js api handler,
 *  see [official doc](https://nextjs.org/docs/api-routes/introduction) for more details
 */
export declare type NextHandler<T = unknown> = (req: NextApiRequest, res?: NextApiResponse) => T | Promise<T>;
/**
 *  all api response combines success response & error response
 */
export declare type ApiResponse<T = unknown> = SuccessApiResponse<T> | ErrorApiResponse;
/**
 *  api response that has http status code 2xx with data
 */
export declare type SuccessApiResponse<T> = {
    success: true;
    data: T;
};
/**
 *  api response that has http status code 4xx or 5xx with error message
 */
export declare type ErrorApiResponse = {
    success: false;
    message: string;
};
/**
 * A router builder is next api handler builder that expose express-like api.
 *
 * ### Example (basic usage)
 * ```js
 * // In next.js /pages/api/[route]
 * import { RouterBuilder } from 'next-api-handler'
 * const handler = new RouterBuilder().build()
 * export default handler
 * ```
 *
 * ### Example (add RESTful method)
 * ```js
 * import { RouterBuilder } from 'next-api-handler'
 * const handler = new RouterBuilder().get((req, res) => "RESPONSE")
 * export default handler
 * ```
 *
 * ### Example (add async method)
 * ```js
 * import { RouterBuilder } from 'next-api-handler'
 * const handler = new RouterBuilder().get(async (req, res) => "ASYNC RESPONSE")
 * export default handler
 * ```
 *
 * @returns a builder that can build a next.js api handler.
 */
export declare class RouterBuilder {
    private readonly route;
    get<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    head<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    patch<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    options<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    connect<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    delete<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    trace<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    post<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    put<T = unknown>(handler: NextHandler<T>): RouterBuilder;
    build(): NextApiHandler;
    private add;
}
